@@ -1,14 +1,10 @@
 import time
 import importlib
 import copy
-import subprocess
-import sys
 
 from connexion import request
-import paddle
 
 from paddlelabel_ml.util import abort, get_models
-from paddlelabel_ml.model.base.model import BaseModel
 
 
 # TODO: switch to a thread safe approach
@@ -20,6 +16,7 @@ loading_models = set()
 models = get_models()
 
 
+# TODO: change this to return version
 def isBackendUp():
     return True
 
@@ -36,7 +33,7 @@ def getProgress():
 
 
 def train(model_name):
-    load(model_name, reload=True)
+    load(model_name, reload=True)  # TODO: this is causing bug?
     model = loaded_models[model_name]
 
     if model.training:
@@ -61,18 +58,6 @@ def getProgresss(model_name):
     pass
 
 
-async def predict(model_name):
-    tic = time.time()
-    if model_name not in loaded_models.keys():
-        abort(f"Model {model_name} not loaded, call load endpoint first!", 500)
-    if model_name in loading_models:
-        abort(f"Model {model_name} is still loading, check back after 1 or 2 minutes!", 500)
-
-    res = {"predictions": loaded_models[model_name].predict(request.json)}
-    print(f"Inference took {time.time() - tic} s")
-    return res
-
-
 async def load(model_name, reload=False):
     tic = time.time()
 
@@ -106,6 +91,27 @@ async def load(model_name, reload=False):
     return f"Model {model_name} loaded", 200
 
 
+async def predict(model_name):
+    tic = time.time()
+    if model_name not in loaded_models.keys():
+        abort(f"Model {model_name} not loaded, call load endpoint first!", 500)
+    if model_name in loading_models:
+        abort(f"Model {model_name} is still loading, check back after 1 or 2 minutes!", 500)
+
+    params = request.json
+    if "piggyback" in params.keys():
+        piggy_value = params["piggyback"]
+        del params["piggyback"]
+    else:
+        piggy_value = None
+
+    res = {"predictions": loaded_models[model_name].predict(request.json)}
+    if piggy_value is not None:
+        res["piggyback"] = piggy_value
+    print(f"Inference took {time.time() - tic} s")
+    return res
+
+
 def unload(model_name):
     if model_name not in models.keys():
         abort(f"No model named {model_name}", 404)
